Manual

Struct Manual 

pub struct Manual<S> { /* private fields */ }
A strategy wrapper for manually partitioned work.

This disables adaptive serial-vs-parallel policy decisions for operations that callers have already split into partitions.

Implementations

Source

impl<S> Manual<S>

pub const fn new(strategy: S, parallelism: NonZeroUsize) -> Self

Creates a strategy wrapper for manually partitioned work.

pub const fn parallelism(&self) -> usize

Returns the parallelism to use for manually partitioned work.