pub struct Manual<S> { /* private fields */ }Expand description
A strategy wrapper for manually partitioned work.
This disables adaptive serial-vs-parallel policy decisions for operations that callers have already split into partitions.
Implementations
Sourceimpl<S> Manual<S>
impl<S> Manual<S>
Sourcepub const fn new(strategy: S, parallelism: NonZeroUsize) -> Self
pub const fn new(strategy: S, parallelism: NonZeroUsize) -> Self
Creates a strategy wrapper for manually partitioned work.
Sourcepub const fn parallelism(&self) -> usize
pub const fn parallelism(&self) -> usize
Returns the parallelism to use for manually partitioned work.